<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>OptionsWidget</name>
    <message>
        <location filename="../../OptionsWidget.ui" line="17"/>
        <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
        <translation>Dans la plupart des cas, seule la DLL 64 bits est importante pour un OS 64 bits, et la DLL 32 bits pour un OS 32 bits. Lorsqu&apos;elle est importante,le chargement d&apos;une DLL peut nécessiter une confirmation (UAC).</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="20"/>
        <source>All the dlls are importants</source>
        <translation>Toutes les dlls sont importantes</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="34"/>
        <source>Register for all users</source>
        <translation>Enregistrer pour tous les utilisateurs</translation>
    </message>
</context>
</TS>
